import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { ButtonProps } from '@highlight-ui/button';
import { TooltipProps } from '@highlight-ui/tooltip';
import { ModalProps } from './Modal';
export declare type DialogActionButtonProps = PropsWithMetadata<{
    /** if tooltip true passing tooltip props except of children */
    tooltip?: Omit<TooltipProps, 'children'>;
    /** Sets the button click handler */
    onClick?: () => void;
    /** Sets the state of the button */
    buttonState?: ButtonProps['buttonState'];
    /** Sets the button label */
    buttonLabel?: string;
    /** Sets the button icon */
    buttonIcon?: string;
    /** Sets the icon button aria label */
    buttonAriaLabel?: string;
    /** Sets HTML button "type" attribute */
    buttonType?: ButtonProps['type'];
    /** Sets HTML button "form" attribute */
    buttonForm?: ButtonProps['form'];
}>;
export declare type DialogProps = ModalProps & {
    /** Sets the title of the dialog  */
    title: string;
    /** Sets the reference to the aria-labelledby attribute. It'll add a default value if not present. */
    labelledBy?: string;
    /** Sets the reference to the aria-describedby attribute */
    describedBy?: string;
    /** `default` is used for regular interactions and `destructive` is usually for destructing (e.g. deletion) */
    variant?: 'default' | 'destructive';
    /** Sets the width of the dialog */
    size?: 'small' | 'medium' | 'large';
    /** Configures the label/icon and behaviour of the primary action button */
    primaryButton?: DialogActionButtonProps;
    /** Configures the label/icon and behaviour of the secondary action buttons */
    secondaryButtons?: DialogActionButtonProps[];
};
declare const Dialog: ({ metadata, children, className, onRequestToClose, onClose, onOpen, open, title, labelledBy, describedBy, primaryButton, secondaryButtons, variant, size, }: DialogProps) => JSX.Element;
export default Dialog;
